# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from powergate.admin.v1 import admin_pb2 as powergate_dot_admin_dot_v1_dot_admin__pb2


class AdminServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.NewAddress = channel.unary_unary(
                '/powergate.admin.v1.AdminService/NewAddress',
                request_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.NewAddressRequest.SerializeToString,
                response_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.NewAddressResponse.FromString,
                )
        self.Addresses = channel.unary_unary(
                '/powergate.admin.v1.AdminService/Addresses',
                request_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.AddressesRequest.SerializeToString,
                response_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.AddressesResponse.FromString,
                )
        self.SendFil = channel.unary_unary(
                '/powergate.admin.v1.AdminService/SendFil',
                request_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.SendFilRequest.SerializeToString,
                response_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.SendFilResponse.FromString,
                )
        self.CreateUser = channel.unary_unary(
                '/powergate.admin.v1.AdminService/CreateUser',
                request_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.CreateUserRequest.SerializeToString,
                response_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.CreateUserResponse.FromString,
                )
        self.Users = channel.unary_unary(
                '/powergate.admin.v1.AdminService/Users',
                request_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.UsersRequest.SerializeToString,
                response_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.UsersResponse.FromString,
                )
        self.QueuedStorageJobs = channel.unary_unary(
                '/powergate.admin.v1.AdminService/QueuedStorageJobs',
                request_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.QueuedStorageJobsRequest.SerializeToString,
                response_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.QueuedStorageJobsResponse.FromString,
                )
        self.ExecutingStorageJobs = channel.unary_unary(
                '/powergate.admin.v1.AdminService/ExecutingStorageJobs',
                request_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.ExecutingStorageJobsRequest.SerializeToString,
                response_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.ExecutingStorageJobsResponse.FromString,
                )
        self.LatestFinalStorageJobs = channel.unary_unary(
                '/powergate.admin.v1.AdminService/LatestFinalStorageJobs',
                request_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.LatestFinalStorageJobsRequest.SerializeToString,
                response_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.LatestFinalStorageJobsResponse.FromString,
                )
        self.LatestSuccessfulStorageJobs = channel.unary_unary(
                '/powergate.admin.v1.AdminService/LatestSuccessfulStorageJobs',
                request_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.LatestSuccessfulStorageJobsRequest.SerializeToString,
                response_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.LatestSuccessfulStorageJobsResponse.FromString,
                )
        self.StorageJobsSummary = channel.unary_unary(
                '/powergate.admin.v1.AdminService/StorageJobsSummary',
                request_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.StorageJobsSummaryRequest.SerializeToString,
                response_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.StorageJobsSummaryResponse.FromString,
                )
        self.GCStaged = channel.unary_unary(
                '/powergate.admin.v1.AdminService/GCStaged',
                request_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.GCStagedRequest.SerializeToString,
                response_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.GCStagedResponse.FromString,
                )
        self.PinnedCids = channel.unary_unary(
                '/powergate.admin.v1.AdminService/PinnedCids',
                request_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.PinnedCidsRequest.SerializeToString,
                response_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.PinnedCidsResponse.FromString,
                )


class AdminServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def NewAddress(self, request, context):
        """Wallet
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Addresses(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendFil(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateUser(self, request, context):
        """Users
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Users(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QueuedStorageJobs(self, request, context):
        """Jobs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExecutingStorageJobs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LatestFinalStorageJobs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LatestSuccessfulStorageJobs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StorageJobsSummary(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GCStaged(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PinnedCids(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AdminServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'NewAddress': grpc.unary_unary_rpc_method_handler(
                    servicer.NewAddress,
                    request_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.NewAddressRequest.FromString,
                    response_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.NewAddressResponse.SerializeToString,
            ),
            'Addresses': grpc.unary_unary_rpc_method_handler(
                    servicer.Addresses,
                    request_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.AddressesRequest.FromString,
                    response_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.AddressesResponse.SerializeToString,
            ),
            'SendFil': grpc.unary_unary_rpc_method_handler(
                    servicer.SendFil,
                    request_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.SendFilRequest.FromString,
                    response_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.SendFilResponse.SerializeToString,
            ),
            'CreateUser': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateUser,
                    request_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.CreateUserRequest.FromString,
                    response_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.CreateUserResponse.SerializeToString,
            ),
            'Users': grpc.unary_unary_rpc_method_handler(
                    servicer.Users,
                    request_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.UsersRequest.FromString,
                    response_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.UsersResponse.SerializeToString,
            ),
            'QueuedStorageJobs': grpc.unary_unary_rpc_method_handler(
                    servicer.QueuedStorageJobs,
                    request_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.QueuedStorageJobsRequest.FromString,
                    response_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.QueuedStorageJobsResponse.SerializeToString,
            ),
            'ExecutingStorageJobs': grpc.unary_unary_rpc_method_handler(
                    servicer.ExecutingStorageJobs,
                    request_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.ExecutingStorageJobsRequest.FromString,
                    response_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.ExecutingStorageJobsResponse.SerializeToString,
            ),
            'LatestFinalStorageJobs': grpc.unary_unary_rpc_method_handler(
                    servicer.LatestFinalStorageJobs,
                    request_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.LatestFinalStorageJobsRequest.FromString,
                    response_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.LatestFinalStorageJobsResponse.SerializeToString,
            ),
            'LatestSuccessfulStorageJobs': grpc.unary_unary_rpc_method_handler(
                    servicer.LatestSuccessfulStorageJobs,
                    request_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.LatestSuccessfulStorageJobsRequest.FromString,
                    response_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.LatestSuccessfulStorageJobsResponse.SerializeToString,
            ),
            'StorageJobsSummary': grpc.unary_unary_rpc_method_handler(
                    servicer.StorageJobsSummary,
                    request_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.StorageJobsSummaryRequest.FromString,
                    response_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.StorageJobsSummaryResponse.SerializeToString,
            ),
            'GCStaged': grpc.unary_unary_rpc_method_handler(
                    servicer.GCStaged,
                    request_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.GCStagedRequest.FromString,
                    response_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.GCStagedResponse.SerializeToString,
            ),
            'PinnedCids': grpc.unary_unary_rpc_method_handler(
                    servicer.PinnedCids,
                    request_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.PinnedCidsRequest.FromString,
                    response_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.PinnedCidsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'powergate.admin.v1.AdminService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AdminService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def NewAddress(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.admin.v1.AdminService/NewAddress',
            powergate_dot_admin_dot_v1_dot_admin__pb2.NewAddressRequest.SerializeToString,
            powergate_dot_admin_dot_v1_dot_admin__pb2.NewAddressResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Addresses(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.admin.v1.AdminService/Addresses',
            powergate_dot_admin_dot_v1_dot_admin__pb2.AddressesRequest.SerializeToString,
            powergate_dot_admin_dot_v1_dot_admin__pb2.AddressesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendFil(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.admin.v1.AdminService/SendFil',
            powergate_dot_admin_dot_v1_dot_admin__pb2.SendFilRequest.SerializeToString,
            powergate_dot_admin_dot_v1_dot_admin__pb2.SendFilResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.admin.v1.AdminService/CreateUser',
            powergate_dot_admin_dot_v1_dot_admin__pb2.CreateUserRequest.SerializeToString,
            powergate_dot_admin_dot_v1_dot_admin__pb2.CreateUserResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Users(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.admin.v1.AdminService/Users',
            powergate_dot_admin_dot_v1_dot_admin__pb2.UsersRequest.SerializeToString,
            powergate_dot_admin_dot_v1_dot_admin__pb2.UsersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QueuedStorageJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.admin.v1.AdminService/QueuedStorageJobs',
            powergate_dot_admin_dot_v1_dot_admin__pb2.QueuedStorageJobsRequest.SerializeToString,
            powergate_dot_admin_dot_v1_dot_admin__pb2.QueuedStorageJobsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExecutingStorageJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.admin.v1.AdminService/ExecutingStorageJobs',
            powergate_dot_admin_dot_v1_dot_admin__pb2.ExecutingStorageJobsRequest.SerializeToString,
            powergate_dot_admin_dot_v1_dot_admin__pb2.ExecutingStorageJobsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LatestFinalStorageJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.admin.v1.AdminService/LatestFinalStorageJobs',
            powergate_dot_admin_dot_v1_dot_admin__pb2.LatestFinalStorageJobsRequest.SerializeToString,
            powergate_dot_admin_dot_v1_dot_admin__pb2.LatestFinalStorageJobsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LatestSuccessfulStorageJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.admin.v1.AdminService/LatestSuccessfulStorageJobs',
            powergate_dot_admin_dot_v1_dot_admin__pb2.LatestSuccessfulStorageJobsRequest.SerializeToString,
            powergate_dot_admin_dot_v1_dot_admin__pb2.LatestSuccessfulStorageJobsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StorageJobsSummary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.admin.v1.AdminService/StorageJobsSummary',
            powergate_dot_admin_dot_v1_dot_admin__pb2.StorageJobsSummaryRequest.SerializeToString,
            powergate_dot_admin_dot_v1_dot_admin__pb2.StorageJobsSummaryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GCStaged(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.admin.v1.AdminService/GCStaged',
            powergate_dot_admin_dot_v1_dot_admin__pb2.GCStagedRequest.SerializeToString,
            powergate_dot_admin_dot_v1_dot_admin__pb2.GCStagedResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PinnedCids(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.admin.v1.AdminService/PinnedCids',
            powergate_dot_admin_dot_v1_dot_admin__pb2.PinnedCidsRequest.SerializeToString,
            powergate_dot_admin_dot_v1_dot_admin__pb2.PinnedCidsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: powergate/admin/v1/admin.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from powergate.user.v1 import user_pb2 as powergate_dot_user_dot_v1_dot_user__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='powergate/admin/v1/admin.proto',
  package='powergate.admin.v1',
  syntax='proto3',
  serialized_options=b'ZAgithub.com/textileio/powergate/api/gen/powergate/admin/v1;adminPb',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1epowergate/admin/v1/admin.proto\x12\x12powergate.admin.v1\x1a\x1cpowergate/user/v1/user.proto\")\n\x11NewAddressRequest\x12\x14\n\x0c\x61\x64\x64ress_type\x18\x01 \x01(\t\"%\n\x12NewAddressResponse\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"\x12\n\x10\x41\x64\x64ressesRequest\"&\n\x11\x41\x64\x64ressesResponse\x12\x11\n\taddresses\x18\x01 \x03(\t\":\n\x0eSendFilRequest\x12\x0c\n\x04\x66rom\x18\x01 \x01(\t\x12\n\n\x02to\x18\x02 \x01(\t\x12\x0e\n\x06\x61mount\x18\x03 \x01(\t\"\x11\n\x0fSendFilResponse\"!\n\x04User\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05token\x18\x02 \x01(\t\"\x13\n\x11\x43reateUserRequest\"<\n\x12\x43reateUserResponse\x12&\n\x04user\x18\x01 \x01(\x0b\x32\x18.powergate.admin.v1.User\"\x0e\n\x0cUsersRequest\"8\n\rUsersResponse\x12\'\n\x05users\x18\x01 \x03(\x0b\x32\x18.powergate.admin.v1.User\"9\n\x18QueuedStorageJobsRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0c\n\x04\x63ids\x18\x02 \x03(\t\"P\n\x19QueuedStorageJobsResponse\x12\x33\n\x0cstorage_jobs\x18\x01 \x03(\x0b\x32\x1d.powergate.user.v1.StorageJob\"<\n\x1b\x45xecutingStorageJobsRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0c\n\x04\x63ids\x18\x02 \x03(\t\"S\n\x1c\x45xecutingStorageJobsResponse\x12\x33\n\x0cstorage_jobs\x18\x01 \x03(\x0b\x32\x1d.powergate.user.v1.StorageJob\">\n\x1dLatestFinalStorageJobsRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0c\n\x04\x63ids\x18\x02 \x03(\t\"U\n\x1eLatestFinalStorageJobsResponse\x12\x33\n\x0cstorage_jobs\x18\x01 \x03(\x0b\x32\x1d.powergate.user.v1.StorageJob\"C\n\"LatestSuccessfulStorageJobsRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0c\n\x04\x63ids\x18\x02 \x03(\t\"Z\n#LatestSuccessfulStorageJobsResponse\x12\x33\n\x0cstorage_jobs\x18\x01 \x03(\x0b\x32\x1d.powergate.user.v1.StorageJob\":\n\x19StorageJobsSummaryRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0c\n\x04\x63ids\x18\x02 \x03(\t\"\xd2\x02\n\x1aStorageJobsSummaryResponse\x12\x30\n\njob_counts\x18\x01 \x01(\x0b\x32\x1c.powergate.user.v1.JobCounts\x12:\n\x13queued_storage_jobs\x18\x02 \x03(\x0b\x32\x1d.powergate.user.v1.StorageJob\x12=\n\x16\x65xecuting_storage_jobs\x18\x03 \x03(\x0b\x32\x1d.powergate.user.v1.StorageJob\x12@\n\x19latest_final_storage_jobs\x18\x04 \x03(\x0b\x32\x1d.powergate.user.v1.StorageJob\x12\x45\n\x1elatest_successful_storage_jobs\x18\x05 \x03(\x0b\x32\x1d.powergate.user.v1.StorageJob\"\x11\n\x0fGCStagedRequest\")\n\x10GCStagedResponse\x12\x15\n\runpinned_cids\x18\x01 \x03(\t\"\x13\n\x11PinnedCidsRequest\"C\n\x12PinnedCidsResponse\x12-\n\x04\x63ids\x18\x01 \x03(\x0b\x32\x1f.powergate.admin.v1.HSPinnedCid\"N\n\x0bHSPinnedCid\x12\x0b\n\x03\x63id\x18\x01 \x01(\t\x12\x32\n\x05users\x18\x02 \x03(\x0b\x32#.powergate.admin.v1.HSPinnedCidUser\"F\n\x0fHSPinnedCidUser\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0e\n\x06staged\x18\x02 \x01(\x08\x12\x12\n\ncreated_at\x18\x03 \x01(\x03\x32\x85\n\n\x0c\x41\x64minService\x12]\n\nNewAddress\x12%.powergate.admin.v1.NewAddressRequest\x1a&.powergate.admin.v1.NewAddressResponse\"\x00\x12Z\n\tAddresses\x12$.powergate.admin.v1.AddressesRequest\x1a%.powergate.admin.v1.AddressesResponse\"\x00\x12T\n\x07SendFil\x12\".powergate.admin.v1.SendFilRequest\x1a#.powergate.admin.v1.SendFilResponse\"\x00\x12]\n\nCreateUser\x12%.powergate.admin.v1.CreateUserRequest\x1a&.powergate.admin.v1.CreateUserResponse\"\x00\x12N\n\x05Users\x12 .powergate.admin.v1.UsersRequest\x1a!.powergate.admin.v1.UsersResponse\"\x00\x12r\n\x11QueuedStorageJobs\x12,.powergate.admin.v1.QueuedStorageJobsRequest\x1a-.powergate.admin.v1.QueuedStorageJobsResponse\"\x00\x12{\n\x14\x45xecutingStorageJobs\x12/.powergate.admin.v1.ExecutingStorageJobsRequest\x1a\x30.powergate.admin.v1.ExecutingStorageJobsResponse\"\x00\x12\x81\x01\n\x16LatestFinalStorageJobs\x12\x31.powergate.admin.v1.LatestFinalStorageJobsRequest\x1a\x32.powergate.admin.v1.LatestFinalStorageJobsResponse\"\x00\x12\x90\x01\n\x1bLatestSuccessfulStorageJobs\x12\x36.powergate.admin.v1.LatestSuccessfulStorageJobsRequest\x1a\x37.powergate.admin.v1.LatestSuccessfulStorageJobsResponse\"\x00\x12u\n\x12StorageJobsSummary\x12-.powergate.admin.v1.StorageJobsSummaryRequest\x1a..powergate.admin.v1.StorageJobsSummaryResponse\"\x00\x12W\n\x08GCStaged\x12#.powergate.admin.v1.GCStagedRequest\x1a$.powergate.admin.v1.GCStagedResponse\"\x00\x12]\n\nPinnedCids\x12%.powergate.admin.v1.PinnedCidsRequest\x1a&.powergate.admin.v1.PinnedCidsResponse\"\x00\x42\x43ZAgithub.com/textileio/powergate/api/gen/powergate/admin/v1;adminPbb\x06proto3'
  ,
  dependencies=[powergate_dot_user_dot_v1_dot_user__pb2.DESCRIPTOR,])




_NEWADDRESSREQUEST = _descriptor.Descriptor(
  name='NewAddressRequest',
  full_name='powergate.admin.v1.NewAddressRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address_type', full_name='powergate.admin.v1.NewAddressRequest.address_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=84,
  serialized_end=125,
)


_NEWADDRESSRESPONSE = _descriptor.Descriptor(
  name='NewAddressResponse',
  full_name='powergate.admin.v1.NewAddressResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='powergate.admin.v1.NewAddressResponse.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=127,
  serialized_end=164,
)


_ADDRESSESREQUEST = _descriptor.Descriptor(
  name='AddressesRequest',
  full_name='powergate.admin.v1.AddressesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=166,
  serialized_end=184,
)


_ADDRESSESRESPONSE = _descriptor.Descriptor(
  name='AddressesResponse',
  full_name='powergate.admin.v1.AddressesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='addresses', full_name='powergate.admin.v1.AddressesResponse.addresses', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=186,
  serialized_end=224,
)


_SENDFILREQUEST = _descriptor.Descriptor(
  name='SendFilRequest',
  full_name='powergate.admin.v1.SendFilRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='from', full_name='powergate.admin.v1.SendFilRequest.from', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to', full_name='powergate.admin.v1.SendFilRequest.to', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='powergate.admin.v1.SendFilRequest.amount', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=226,
  serialized_end=284,
)


_SENDFILRESPONSE = _descriptor.Descriptor(
  name='SendFilResponse',
  full_name='powergate.admin.v1.SendFilResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=286,
  serialized_end=303,
)


_USER = _descriptor.Descriptor(
  name='User',
  full_name='powergate.admin.v1.User',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='powergate.admin.v1.User.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token', full_name='powergate.admin.v1.User.token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=305,
  serialized_end=338,
)


_CREATEUSERREQUEST = _descriptor.Descriptor(
  name='CreateUserRequest',
  full_name='powergate.admin.v1.CreateUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=340,
  serialized_end=359,
)


_CREATEUSERRESPONSE = _descriptor.Descriptor(
  name='CreateUserResponse',
  full_name='powergate.admin.v1.CreateUserResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='powergate.admin.v1.CreateUserResponse.user', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=361,
  serialized_end=421,
)


_USERSREQUEST = _descriptor.Descriptor(
  name='UsersRequest',
  full_name='powergate.admin.v1.UsersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=423,
  serialized_end=437,
)


_USERSRESPONSE = _descriptor.Descriptor(
  name='UsersResponse',
  full_name='powergate.admin.v1.UsersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='users', full_name='powergate.admin.v1.UsersResponse.users', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=439,
  serialized_end=495,
)


_QUEUEDSTORAGEJOBSREQUEST = _descriptor.Descriptor(
  name='QueuedStorageJobsRequest',
  full_name='powergate.admin.v1.QueuedStorageJobsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='powergate.admin.v1.QueuedStorageJobsRequest.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cids', full_name='powergate.admin.v1.QueuedStorageJobsRequest.cids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=497,
  serialized_end=554,
)


_QUEUEDSTORAGEJOBSRESPONSE = _descriptor.Descriptor(
  name='QueuedStorageJobsResponse',
  full_name='powergate.admin.v1.QueuedStorageJobsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage_jobs', full_name='powergate.admin.v1.QueuedStorageJobsResponse.storage_jobs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=556,
  serialized_end=636,
)


_EXECUTINGSTORAGEJOBSREQUEST = _descriptor.Descriptor(
  name='ExecutingStorageJobsRequest',
  full_name='powergate.admin.v1.ExecutingStorageJobsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='powergate.admin.v1.ExecutingStorageJobsRequest.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cids', full_name='powergate.admin.v1.ExecutingStorageJobsRequest.cids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=638,
  serialized_end=698,
)


_EXECUTINGSTORAGEJOBSRESPONSE = _descriptor.Descriptor(
  name='ExecutingStorageJobsResponse',
  full_name='powergate.admin.v1.ExecutingStorageJobsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage_jobs', full_name='powergate.admin.v1.ExecutingStorageJobsResponse.storage_jobs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=700,
  serialized_end=783,
)


_LATESTFINALSTORAGEJOBSREQUEST = _descriptor.Descriptor(
  name='LatestFinalStorageJobsRequest',
  full_name='powergate.admin.v1.LatestFinalStorageJobsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='powergate.admin.v1.LatestFinalStorageJobsRequest.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cids', full_name='powergate.admin.v1.LatestFinalStorageJobsRequest.cids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=785,
  serialized_end=847,
)


_LATESTFINALSTORAGEJOBSRESPONSE = _descriptor.Descriptor(
  name='LatestFinalStorageJobsResponse',
  full_name='powergate.admin.v1.LatestFinalStorageJobsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage_jobs', full_name='powergate.admin.v1.LatestFinalStorageJobsResponse.storage_jobs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=849,
  serialized_end=934,
)


_LATESTSUCCESSFULSTORAGEJOBSREQUEST = _descriptor.Descriptor(
  name='LatestSuccessfulStorageJobsRequest',
  full_name='powergate.admin.v1.LatestSuccessfulStorageJobsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='powergate.admin.v1.LatestSuccessfulStorageJobsRequest.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cids', full_name='powergate.admin.v1.LatestSuccessfulStorageJobsRequest.cids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=936,
  serialized_end=1003,
)


_LATESTSUCCESSFULSTORAGEJOBSRESPONSE = _descriptor.Descriptor(
  name='LatestSuccessfulStorageJobsResponse',
  full_name='powergate.admin.v1.LatestSuccessfulStorageJobsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage_jobs', full_name='powergate.admin.v1.LatestSuccessfulStorageJobsResponse.storage_jobs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1005,
  serialized_end=1095,
)


_STORAGEJOBSSUMMARYREQUEST = _descriptor.Descriptor(
  name='StorageJobsSummaryRequest',
  full_name='powergate.admin.v1.StorageJobsSummaryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='powergate.admin.v1.StorageJobsSummaryRequest.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cids', full_name='powergate.admin.v1.StorageJobsSummaryRequest.cids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1097,
  serialized_end=1155,
)


_STORAGEJOBSSUMMARYRESPONSE = _descriptor.Descriptor(
  name='StorageJobsSummaryResponse',
  full_name='powergate.admin.v1.StorageJobsSummaryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='job_counts', full_name='powergate.admin.v1.StorageJobsSummaryResponse.job_counts', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='queued_storage_jobs', full_name='powergate.admin.v1.StorageJobsSummaryResponse.queued_storage_jobs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='executing_storage_jobs', full_name='powergate.admin.v1.StorageJobsSummaryResponse.executing_storage_jobs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latest_final_storage_jobs', full_name='powergate.admin.v1.StorageJobsSummaryResponse.latest_final_storage_jobs', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latest_successful_storage_jobs', full_name='powergate.admin.v1.StorageJobsSummaryResponse.latest_successful_storage_jobs', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1158,
  serialized_end=1496,
)


_GCSTAGEDREQUEST = _descriptor.Descriptor(
  name='GCStagedRequest',
  full_name='powergate.admin.v1.GCStagedRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1498,
  serialized_end=1515,
)


_GCSTAGEDRESPONSE = _descriptor.Descriptor(
  name='GCStagedResponse',
  full_name='powergate.admin.v1.GCStagedResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='unpinned_cids', full_name='powergate.admin.v1.GCStagedResponse.unpinned_cids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1517,
  serialized_end=1558,
)


_PINNEDCIDSREQUEST = _descriptor.Descriptor(
  name='PinnedCidsRequest',
  full_name='powergate.admin.v1.PinnedCidsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1560,
  serialized_end=1579,
)


_PINNEDCIDSRESPONSE = _descriptor.Descriptor(
  name='PinnedCidsResponse',
  full_name='powergate.admin.v1.PinnedCidsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cids', full_name='powergate.admin.v1.PinnedCidsResponse.cids', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1581,
  serialized_end=1648,
)


_HSPINNEDCID = _descriptor.Descriptor(
  name='HSPinnedCid',
  full_name='powergate.admin.v1.HSPinnedCid',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cid', full_name='powergate.admin.v1.HSPinnedCid.cid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='users', full_name='powergate.admin.v1.HSPinnedCid.users', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1650,
  serialized_end=1728,
)


_HSPINNEDCIDUSER = _descriptor.Descriptor(
  name='HSPinnedCidUser',
  full_name='powergate.admin.v1.HSPinnedCidUser',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='powergate.admin.v1.HSPinnedCidUser.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='staged', full_name='powergate.admin.v1.HSPinnedCidUser.staged', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='powergate.admin.v1.HSPinnedCidUser.created_at', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1730,
  serialized_end=1800,
)

_CREATEUSERRESPONSE.fields_by_name['user'].message_type = _USER
_USERSRESPONSE.fields_by_name['users'].message_type = _USER
_QUEUEDSTORAGEJOBSRESPONSE.fields_by_name['storage_jobs'].message_type = powergate_dot_user_dot_v1_dot_user__pb2._STORAGEJOB
_EXECUTINGSTORAGEJOBSRESPONSE.fields_by_name['storage_jobs'].message_type = powergate_dot_user_dot_v1_dot_user__pb2._STORAGEJOB
_LATESTFINALSTORAGEJOBSRESPONSE.fields_by_name['storage_jobs'].message_type = powergate_dot_user_dot_v1_dot_user__pb2._STORAGEJOB
_LATESTSUCCESSFULSTORAGEJOBSRESPONSE.fields_by_name['storage_jobs'].message_type = powergate_dot_user_dot_v1_dot_user__pb2._STORAGEJOB
_STORAGEJOBSSUMMARYRESPONSE.fields_by_name['job_counts'].message_type = powergate_dot_user_dot_v1_dot_user__pb2._JOBCOUNTS
_STORAGEJOBSSUMMARYRESPONSE.fields_by_name['queued_storage_jobs'].message_type = powergate_dot_user_dot_v1_dot_user__pb2._STORAGEJOB
_STORAGEJOBSSUMMARYRESPONSE.fields_by_name['executing_storage_jobs'].message_type = powergate_dot_user_dot_v1_dot_user__pb2._STORAGEJOB
_STORAGEJOBSSUMMARYRESPONSE.fields_by_name['latest_final_storage_jobs'].message_type = powergate_dot_user_dot_v1_dot_user__pb2._STORAGEJOB
_STORAGEJOBSSUMMARYRESPONSE.fields_by_name['latest_successful_storage_jobs'].message_type = powergate_dot_user_dot_v1_dot_user__pb2._STORAGEJOB
_PINNEDCIDSRESPONSE.fields_by_name['cids'].message_type = _HSPINNEDCID
_HSPINNEDCID.fields_by_name['users'].message_type = _HSPINNEDCIDUSER
DESCRIPTOR.message_types_by_name['NewAddressRequest'] = _NEWADDRESSREQUEST
DESCRIPTOR.message_types_by_name['NewAddressResponse'] = _NEWADDRESSRESPONSE
DESCRIPTOR.message_types_by_name['AddressesRequest'] = _ADDRESSESREQUEST
DESCRIPTOR.message_types_by_name['AddressesResponse'] = _ADDRESSESRESPONSE
DESCRIPTOR.message_types_by_name['SendFilRequest'] = _SENDFILREQUEST
DESCRIPTOR.message_types_by_name['SendFilResponse'] = _SENDFILRESPONSE
DESCRIPTOR.message_types_by_name['User'] = _USER
DESCRIPTOR.message_types_by_name['CreateUserRequest'] = _CREATEUSERREQUEST
DESCRIPTOR.message_types_by_name['CreateUserResponse'] = _CREATEUSERRESPONSE
DESCRIPTOR.message_types_by_name['UsersRequest'] = _USERSREQUEST
DESCRIPTOR.message_types_by_name['UsersResponse'] = _USERSRESPONSE
DESCRIPTOR.message_types_by_name['QueuedStorageJobsRequest'] = _QUEUEDSTORAGEJOBSREQUEST
DESCRIPTOR.message_types_by_name['QueuedStorageJobsResponse'] = _QUEUEDSTORAGEJOBSRESPONSE
DESCRIPTOR.message_types_by_name['ExecutingStorageJobsRequest'] = _EXECUTINGSTORAGEJOBSREQUEST
DESCRIPTOR.message_types_by_name['ExecutingStorageJobsResponse'] = _EXECUTINGSTORAGEJOBSRESPONSE
DESCRIPTOR.message_types_by_name['LatestFinalStorageJobsRequest'] = _LATESTFINALSTORAGEJOBSREQUEST
DESCRIPTOR.message_types_by_name['LatestFinalStorageJobsResponse'] = _LATESTFINALSTORAGEJOBSRESPONSE
DESCRIPTOR.message_types_by_name['LatestSuccessfulStorageJobsRequest'] = _LATESTSUCCESSFULSTORAGEJOBSREQUEST
DESCRIPTOR.message_types_by_name['LatestSuccessfulStorageJobsResponse'] = _LATESTSUCCESSFULSTORAGEJOBSRESPONSE
DESCRIPTOR.message_types_by_name['StorageJobsSummaryRequest'] = _STORAGEJOBSSUMMARYREQUEST
DESCRIPTOR.message_types_by_name['StorageJobsSummaryResponse'] = _STORAGEJOBSSUMMARYRESPONSE
DESCRIPTOR.message_types_by_name['GCStagedRequest'] = _GCSTAGEDREQUEST
DESCRIPTOR.message_types_by_name['GCStagedResponse'] = _GCSTAGEDRESPONSE
DESCRIPTOR.message_types_by_name['PinnedCidsRequest'] = _PINNEDCIDSREQUEST
DESCRIPTOR.message_types_by_name['PinnedCidsResponse'] = _PINNEDCIDSRESPONSE
DESCRIPTOR.message_types_by_name['HSPinnedCid'] = _HSPINNEDCID
DESCRIPTOR.message_types_by_name['HSPinnedCidUser'] = _HSPINNEDCIDUSER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

NewAddressRequest = _reflection.GeneratedProtocolMessageType('NewAddressRequest', (_message.Message,), {
  'DESCRIPTOR' : _NEWADDRESSREQUEST,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.NewAddressRequest)
  })
_sym_db.RegisterMessage(NewAddressRequest)

NewAddressResponse = _reflection.GeneratedProtocolMessageType('NewAddressResponse', (_message.Message,), {
  'DESCRIPTOR' : _NEWADDRESSRESPONSE,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.NewAddressResponse)
  })
_sym_db.RegisterMessage(NewAddressResponse)

AddressesRequest = _reflection.GeneratedProtocolMessageType('AddressesRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDRESSESREQUEST,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.AddressesRequest)
  })
_sym_db.RegisterMessage(AddressesRequest)

AddressesResponse = _reflection.GeneratedProtocolMessageType('AddressesResponse', (_message.Message,), {
  'DESCRIPTOR' : _ADDRESSESRESPONSE,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.AddressesResponse)
  })
_sym_db.RegisterMessage(AddressesResponse)

SendFilRequest = _reflection.GeneratedProtocolMessageType('SendFilRequest', (_message.Message,), {
  'DESCRIPTOR' : _SENDFILREQUEST,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.SendFilRequest)
  })
_sym_db.RegisterMessage(SendFilRequest)

SendFilResponse = _reflection.GeneratedProtocolMessageType('SendFilResponse', (_message.Message,), {
  'DESCRIPTOR' : _SENDFILRESPONSE,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.SendFilResponse)
  })
_sym_db.RegisterMessage(SendFilResponse)

User = _reflection.GeneratedProtocolMessageType('User', (_message.Message,), {
  'DESCRIPTOR' : _USER,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.User)
  })
_sym_db.RegisterMessage(User)

CreateUserRequest = _reflection.GeneratedProtocolMessageType('CreateUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEUSERREQUEST,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.CreateUserRequest)
  })
_sym_db.RegisterMessage(CreateUserRequest)

CreateUserResponse = _reflection.GeneratedProtocolMessageType('CreateUserResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEUSERRESPONSE,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.CreateUserResponse)
  })
_sym_db.RegisterMessage(CreateUserResponse)

UsersRequest = _reflection.GeneratedProtocolMessageType('UsersRequest', (_message.Message,), {
  'DESCRIPTOR' : _USERSREQUEST,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.UsersRequest)
  })
_sym_db.RegisterMessage(UsersRequest)

UsersResponse = _reflection.GeneratedProtocolMessageType('UsersResponse', (_message.Message,), {
  'DESCRIPTOR' : _USERSRESPONSE,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.UsersResponse)
  })
_sym_db.RegisterMessage(UsersResponse)

QueuedStorageJobsRequest = _reflection.GeneratedProtocolMessageType('QueuedStorageJobsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUEUEDSTORAGEJOBSREQUEST,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.QueuedStorageJobsRequest)
  })
_sym_db.RegisterMessage(QueuedStorageJobsRequest)

QueuedStorageJobsResponse = _reflection.GeneratedProtocolMessageType('QueuedStorageJobsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUEUEDSTORAGEJOBSRESPONSE,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.QueuedStorageJobsResponse)
  })
_sym_db.RegisterMessage(QueuedStorageJobsResponse)

ExecutingStorageJobsRequest = _reflection.GeneratedProtocolMessageType('ExecutingStorageJobsRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTINGSTORAGEJOBSREQUEST,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.ExecutingStorageJobsRequest)
  })
_sym_db.RegisterMessage(ExecutingStorageJobsRequest)

ExecutingStorageJobsResponse = _reflection.GeneratedProtocolMessageType('ExecutingStorageJobsResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTINGSTORAGEJOBSRESPONSE,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.ExecutingStorageJobsResponse)
  })
_sym_db.RegisterMessage(ExecutingStorageJobsResponse)

LatestFinalStorageJobsRequest = _reflection.GeneratedProtocolMessageType('LatestFinalStorageJobsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LATESTFINALSTORAGEJOBSREQUEST,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.LatestFinalStorageJobsRequest)
  })
_sym_db.RegisterMessage(LatestFinalStorageJobsRequest)

LatestFinalStorageJobsResponse = _reflection.GeneratedProtocolMessageType('LatestFinalStorageJobsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LATESTFINALSTORAGEJOBSRESPONSE,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.LatestFinalStorageJobsResponse)
  })
_sym_db.RegisterMessage(LatestFinalStorageJobsResponse)

LatestSuccessfulStorageJobsRequest = _reflection.GeneratedProtocolMessageType('LatestSuccessfulStorageJobsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LATESTSUCCESSFULSTORAGEJOBSREQUEST,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.LatestSuccessfulStorageJobsRequest)
  })
_sym_db.RegisterMessage(LatestSuccessfulStorageJobsRequest)

LatestSuccessfulStorageJobsResponse = _reflection.GeneratedProtocolMessageType('LatestSuccessfulStorageJobsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LATESTSUCCESSFULSTORAGEJOBSRESPONSE,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.LatestSuccessfulStorageJobsResponse)
  })
_sym_db.RegisterMessage(LatestSuccessfulStorageJobsResponse)

StorageJobsSummaryRequest = _reflection.GeneratedProtocolMessageType('StorageJobsSummaryRequest', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEJOBSSUMMARYREQUEST,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.StorageJobsSummaryRequest)
  })
_sym_db.RegisterMessage(StorageJobsSummaryRequest)

StorageJobsSummaryResponse = _reflection.GeneratedProtocolMessageType('StorageJobsSummaryResponse', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEJOBSSUMMARYRESPONSE,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.StorageJobsSummaryResponse)
  })
_sym_db.RegisterMessage(StorageJobsSummaryResponse)

GCStagedRequest = _reflection.GeneratedProtocolMessageType('GCStagedRequest', (_message.Message,), {
  'DESCRIPTOR' : _GCSTAGEDREQUEST,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.GCStagedRequest)
  })
_sym_db.RegisterMessage(GCStagedRequest)

GCStagedResponse = _reflection.GeneratedProtocolMessageType('GCStagedResponse', (_message.Message,), {
  'DESCRIPTOR' : _GCSTAGEDRESPONSE,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.GCStagedResponse)
  })
_sym_db.RegisterMessage(GCStagedResponse)

PinnedCidsRequest = _reflection.GeneratedProtocolMessageType('PinnedCidsRequest', (_message.Message,), {
  'DESCRIPTOR' : _PINNEDCIDSREQUEST,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.PinnedCidsRequest)
  })
_sym_db.RegisterMessage(PinnedCidsRequest)

PinnedCidsResponse = _reflection.GeneratedProtocolMessageType('PinnedCidsResponse', (_message.Message,), {
  'DESCRIPTOR' : _PINNEDCIDSRESPONSE,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.PinnedCidsResponse)
  })
_sym_db.RegisterMessage(PinnedCidsResponse)

HSPinnedCid = _reflection.GeneratedProtocolMessageType('HSPinnedCid', (_message.Message,), {
  'DESCRIPTOR' : _HSPINNEDCID,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.HSPinnedCid)
  })
_sym_db.RegisterMessage(HSPinnedCid)

HSPinnedCidUser = _reflection.GeneratedProtocolMessageType('HSPinnedCidUser', (_message.Message,), {
  'DESCRIPTOR' : _HSPINNEDCIDUSER,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.HSPinnedCidUser)
  })
_sym_db.RegisterMessage(HSPinnedCidUser)


DESCRIPTOR._options = None

_ADMINSERVICE = _descriptor.ServiceDescriptor(
  name='AdminService',
  full_name='powergate.admin.v1.AdminService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1803,
  serialized_end=3088,
  methods=[
  _descriptor.MethodDescriptor(
    name='NewAddress',
    full_name='powergate.admin.v1.AdminService.NewAddress',
    index=0,
    containing_service=None,
    input_type=_NEWADDRESSREQUEST,
    output_type=_NEWADDRESSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Addresses',
    full_name='powergate.admin.v1.AdminService.Addresses',
    index=1,
    containing_service=None,
    input_type=_ADDRESSESREQUEST,
    output_type=_ADDRESSESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendFil',
    full_name='powergate.admin.v1.AdminService.SendFil',
    index=2,
    containing_service=None,
    input_type=_SENDFILREQUEST,
    output_type=_SENDFILRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateUser',
    full_name='powergate.admin.v1.AdminService.CreateUser',
    index=3,
    containing_service=None,
    input_type=_CREATEUSERREQUEST,
    output_type=_CREATEUSERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Users',
    full_name='powergate.admin.v1.AdminService.Users',
    index=4,
    containing_service=None,
    input_type=_USERSREQUEST,
    output_type=_USERSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='QueuedStorageJobs',
    full_name='powergate.admin.v1.AdminService.QueuedStorageJobs',
    index=5,
    containing_service=None,
    input_type=_QUEUEDSTORAGEJOBSREQUEST,
    output_type=_QUEUEDSTORAGEJOBSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ExecutingStorageJobs',
    full_name='powergate.admin.v1.AdminService.ExecutingStorageJobs',
    index=6,
    containing_service=None,
    input_type=_EXECUTINGSTORAGEJOBSREQUEST,
    output_type=_EXECUTINGSTORAGEJOBSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LatestFinalStorageJobs',
    full_name='powergate.admin.v1.AdminService.LatestFinalStorageJobs',
    index=7,
    containing_service=None,
    input_type=_LATESTFINALSTORAGEJOBSREQUEST,
    output_type=_LATESTFINALSTORAGEJOBSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LatestSuccessfulStorageJobs',
    full_name='powergate.admin.v1.AdminService.LatestSuccessfulStorageJobs',
    index=8,
    containing_service=None,
    input_type=_LATESTSUCCESSFULSTORAGEJOBSREQUEST,
    output_type=_LATESTSUCCESSFULSTORAGEJOBSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StorageJobsSummary',
    full_name='powergate.admin.v1.AdminService.StorageJobsSummary',
    index=9,
    containing_service=None,
    input_type=_STORAGEJOBSSUMMARYREQUEST,
    output_type=_STORAGEJOBSSUMMARYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GCStaged',
    full_name='powergate.admin.v1.AdminService.GCStaged',
    index=10,
    containing_service=None,
    input_type=_GCSTAGEDREQUEST,
    output_type=_GCSTAGEDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PinnedCids',
    full_name='powergate.admin.v1.AdminService.PinnedCids',
    index=11,
    containing_service=None,
    input_type=_PINNEDCIDSREQUEST,
    output_type=_PINNEDCIDSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ADMINSERVICE)

DESCRIPTOR.services_by_name['AdminService'] = _ADMINSERVICE

# @@protoc_insertion_point(module_scope)
